
<a href="https://github.com/warpnet/salt-lint" style="color: black;">
    <h1 align="center">salt-lint</h1>
</a>
<p align="center">
    <a href="https://pypi.org/project/salt-lint/">
        <img src="https://img.shields.io/github/v/release/warpnet/salt-lint?style=for-the-badge"
            alt="Latest release version">
    </a>
    <a href="https://pypi.org/project/salt-lint/">
        <img src="https://img.shields.io/pypi/pyversions/salt-lint?style=for-the-badge"
            alt="PyPI - Python Version">
    </a>
    <a href="https://raw.githubusercontent.com/warpnet/salt-lint/main/LICENSE">
        <img src="https://img.shields.io/pypi/l/salt-lint?style=for-the-badge&color=blue"
            alt="PyPI - License">
    </a>
    <a href="https://github.com/warpnet/salt-lint/actions">
        <img src="https://img.shields.io/github/actions/workflow/status/warpnet/salt-lint/tox.yml?style=for-the-badge&color=blue&branch=main"
            alt="GitHub Workflow Status">
    </a>
    <a href="https://github.com/warpnet/salt-lint/graphs/contributors">
        <img src="https://img.shields.io/github/contributors/warpnet/salt-lint?style=for-the-badge&color=blue"
            alt="GitHub contributors">
    </a>
    </br>
    <b>salt-lint</b> checks Salt State files (SLS) for best practices and behavior that could potentially be improved.
    <br />
    <a href="https://salt-lint.readthedocs.io/en/latest/"><strong>Explore the docs »</strong></a>
    <br />
    <a href="https://salt-lint.readthedocs.io/en/latest/rules/">Check the Linting Rules</a>
    ·
    <a href="https://github.com/warpnet/salt-lint/issues/new?assignees=&labels=Type%3A%20Bug&template=bug_report.md&title=Bug%3A">Report Bug</a>
    ·
    <a href="https://github.com/warpnet/salt-lint/issues/new?assignees=&labels=Type%3A%20Enhancement&template=feature_request.md&title=Feature+Request%3A">Request Feature</a>
</p>

## Demo
[![salt-lint demo](https://raw.githubusercontent.com/warpnet/salt-lint/main/demo.gif?raw=true)](https://asciinema.org/a/377244)

## Acknowledgement
The project is heavily based on [ansible-lint](https://github.com/ansible/ansible-lint), with the modified work by [Warpnet B.V.](https://github.com/warpnet).  [ansible-lint](https://github.com/ansible/ansible-lint) was created by [Will Thames](https://github.com/willthames) and is now maintained as part of the [Ansible](https://www.ansible.com/) by [Red Hat](https://www.redhat.com) project.
